protostrings
============

String-like Objects

* `Documentation <http://protostrings.readthedocs.io/en/latest/>`_
* `Packaging/Distribution/PyPI <https://pypi.python.org/pypi/protostrings/>`_
* `Source/GitHub <https://github.com/orbisvicis/protostrings>`_
